# Changelog

## 0.1.0 - 2024-09-27

First official release of the `sspi` Python module.
This includes both the high and low level API used for interacting with SSPI.
As well as Windows support, there is experimental Linux and macOS support using [sspi-rs](https://github.com/Devolutions/sspi-rs) as the SSPI implementation that ships with the wheels on those platforms.

## 0.0.1 - 2023-09-19

Initial release. This is not meant to be an official release but a way to request the namespace on PyPI.
